UMAP implementation from a pre-computed kNN graph
rs_umap_from_knn_gpu.Rd
This is the wrapper function into the Rust interface for UMAP and takes a
pre-computed kNN graph, skipping the graph build. GPU acceleration applies
to the optimisation.
Usage
rs_umap_from_knn_gpu(
embd,
knn_data,
n_dim,
min_dist,
spread,
k,
umap_params,
seed,
use_high_precision,
verbose
)Arguments
- embd
Numerical matrix. The data to use to generate the embeddings. Should be of dimensions samples x features.
- knn_data
NearestNeighboursclass from R.- n_dim
Integer. Number of UMAP dimensions to return.
- min_dist
Numeric. Minimum distance to use.
- spread
Numeric. Spread parameter to use.
- k
Integer. Number of nearest neighbours to consider
- umap_params
Named list. List that contains all of the key parameters for the UMAP generation.
- seed
Integer. Seed for reproducibility.
- use_high_precision
Optional logical. Controls
fp32vsfp64for. IfNULLwill use sensible default thresholding.- verbose
Integer. If
0L-> silent or1Lfor normal verbosity;2Lfor detailed verbosity.