Predict embeddings for new data using a trained parametric UMAP model
predict.ParametricUmapModel.RdPredict embeddings for new data using a trained parametric UMAP model
Usage
# S3 method for class 'ParametricUmapModel'
predict(object, newdata, ...)